@@ -58,7 +58,6 @@ class InfluxDB(object):
     def get_data(self,bucket_name,*args,return_dataframe=True,as_stream=False,**kwargs):
         query=self.get_flux(bucket_name,*args,return_dataframe=return_dataframe,**kwargs)
         logger.debug(f'Executing query: {query}')
-        print(query)
         query_api = self.client.query_api()
         if return_dataframe:
             return query_api.query_data_frame(query)
@@ -98,7 +97,7 @@ class InfluxDB(object):
             filters.append(get_filter('tag',tags))
         if keep_fields is not None:
             if type(keep_fields) not in [list,tuple,np.ndarray]: keep_fields=[keep_fields]
-            args.extend(keep_fields)
+            args=list(args)+keep_fields
         kwargs.update({x:None for x in args if x not in kwargs})
         if len(kwargs)>0:
             for key,val in kwargs.items():
@@ -114,6 +113,8 @@ class InfluxDB(object):
             extra_flux_commands=[f'{"" if x.startswith(" ") else " "}{"" if x.strip().startswith("|>") else "|> "}{x}' for x in extra_flux_commands]
             flux.extend(extra_flux_commands)
 
+
+
         if return_dataframe:
             flux.append(' |> pivot(rowKey:["_time"], columnKey: ["_field"], valueColumn: "_value")')
         elif keep_keys is not None:
